@@ -3,7 +3,6 @@ from grid.cli.grid_cancel import cancel
 from grid.cli.grid_credentials import credentials
 from grid.cli.grid_datastores import datastores
 from grid.cli.grid_delete import delete
-from grid.cli.grid_deletecluster import deletecluster
 from grid.cli.grid_history import history
 from grid.cli.grid_interactive import interactive
 from grid.cli.grid_login import login
@@ -28,7 +27,6 @@ __all__ = [
     'metrics',
     'interactive',
     'artifacts',
-    'deletecluster',
     'delete',
     'datastores',
     'slurm',
