@@ -3,7 +3,6 @@ from typing import List, Optional
 import click
 
 from grid import Grid
-from grid.utilities import check_is_experiment
 
 
 @click.command()
@@ -12,11 +11,7 @@ from grid.utilities import check_is_experiment
               required=False,
               default='./grid_artifacts',
               help='Download directory that will host all artifact files')
-@click.argument('experiments',
-                type=str,
-                required=True,
-                nargs=-1,
-                callback=check_is_experiment)
+@click.argument('experiments', type=str, required=True, nargs=-1)
 def artifacts(experiments: List[str],
               download_dir: Optional[str] = None) -> None:
     """Downloads artifacts for a given experiment or set of experiments."""
