@@ -10,7 +10,10 @@ from grid.cli.grid_train import get_credentials
 @click.pass_context
 def datastores(ctx) -> None:
     """Manages datastore workflows in Grid"""
-    return
+    client = Grid()
+
+    if ctx.invoked_subcommand is None:
+        client.list_datastores()
 
 
 @datastores.command()
