@@ -5,7 +5,6 @@ import click
 from grid import Grid
 import grid.globals as env
 from grid.types import ObservableType
-from grid.utilities import is_experiment
 
 
 @click.command()
@@ -41,13 +40,6 @@ def status(run: Optional[str] = None,
         observable = [run]
         kind = ObservableType.EXPERIMENT
 
-        # Users cannot see the status of experiments directly,
-        # but need to check the status of a specific run to
-        # see the status of experiments.
-        if is_experiment(observable[0]):
-            raise click.BadArgumentUsage(
-                'You can only check the status of Runs')
-
     client.status(kind=kind,
                   identifiers=observable,
                   follow=follow,
