@@ -1,4 +1,5 @@
 import random
+import shlex
 import sys
 from typing import Any, Dict, Optional
 
@@ -70,9 +71,6 @@ def get_credentials(client: Grid,
 def _check_run_name_is_valid(_ctx, _param, value):
     """Click callback that checks if a Run contains reserved names."""
     if value is not None:
-        if is_experiment(value):
-            raise click.BadParameter('Runs cannot end with "exp[0-1]".')
-
         fail = False
 
         #  Check if the input is alphanumeric.
@@ -249,6 +247,7 @@ def _get_instance_types(ctx, args, incomplete):
         "g4dn.8xlarge",
         "g4dn.4xlarge",
         "g4dn.2xlarge",
+        "g4dn.xlarge",
         "p2.xlarge",
         "g3.4xlarge",
         "g3s.xlarge",
@@ -303,7 +302,7 @@ def _get_instance_types(ctx, args, incomplete):
               '--g_instance_type',
               'instance_type',
               type=str,
-              default='t2.xlarge',
+              default='g3.8xlarge',
               help='Instance type to start training session in',
               autocompletion=_get_instance_types)
 @click.option('--grid_gpus',
@@ -401,10 +400,17 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
           framework: Optional[str]) -> None:
     """Trains scripts in remote infrastructure"""
 
-    #  Captures all other user arguments that are not
-    #  parsed automatically.
+    # Captures all other user arguments that are not
+    # parsed automatically.
     script_arguments = list(script_args)
 
+    # Captures invocation command exactly as it was
+    # typed in the terminal. pipe.quote maintains original
+    # quotation used in the CLI. We'll replace absolute
+    # grid executable path with the `grid` alias.
+    sys.argv[0] = "grid"
+    invocation_command = " ".join(map(shlex.quote, sys.argv))
+
     if env.DEBUG:
         click.echo(f"Script Arguments {script_arguments}")
         click.echo(f"Entrypoint Script: {entrypoint}")
@@ -415,7 +421,7 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
 
     tracker = Segment()
     tracker.send_event(event=TrackingEvents.RUN_CREATED,
-                       properties={'user_input': " ".join(sys.argv)})
+                       properties={'user_input': invocation_command})
 
     # make a fun random name when user does not pass in a name
     if name is None:
@@ -449,6 +455,10 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
 
     validate_config(cfg=_grid_config)
 
+    client.validate_datastore_version(grid_config=_grid_config)
+    datastore_version = _grid_config["compute"]["train"].get(
+        "datastore_version")
+
     # Warn user if they have not specified a cpu or gpu number so cpus will be set to 1
     cpus = _grid_config['compute']['train'].get('cpus')
     gpus = _grid_config['compute']['train'].get('gpus')
@@ -475,7 +485,8 @@ def train(ctx, script: str, entrypoint: str, config: Optional[Dict],
                  run_name=name,
                  run_description=description,
                  entrypoint=entrypoint,
-                 script_args=script_arguments)
+                 script_args=script_arguments,
+                 invocation_command=invocation_command)
 
     #  Shows a friendly submission message to the
     #  user.
