@@ -365,6 +365,33 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
 
         return has_token
 
+    def _check_github_repo_accessible(self, github_repository: str) -> bool:
+        """
+        Checks if user has authoirized Grid to access a given Github repository.
+        If the user did not, then redirect them to the
+        Grid UI settings page to authorize.
+
+        Parameters
+        ----------
+        github_repository: str
+            Github repository URL or ID
+
+        Returns
+        -------
+        is_accessible: bool
+            Boolean indicating if the user authorized to access the Github repository,
+        """
+        result = self.client.execute(
+            gql("""
+            query ($repositoryUrl: ID!) {
+                isGithubRepositoryAccessible(repositoryUrl: $repositoryUrl) {
+                    isAccessible
+                }
+            }"""),
+            variable_values={'repositoryUrl': github_repository})
+
+        return result['isGithubRepositoryAccessible']['isAccessible']
+
     def login(self, username: str, key: str) -> bool:
         """
         Logs into grid, creating a local credential set.
@@ -427,52 +454,9 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
 
         return success
 
-    def delete_cluster(self, cluster_id: str) -> None:
-        """
-        Deletes a cluster from the backend
-
-        Parameters
-        ----------
-        cluster_id: str
-           The id of cluster
-        """
-        mutation = gql("""
-        mutation (
-            $clusterId: ID!
-            ) {
-            deleteCluster (
-              clusterId: $clusterId
-            ) {
-            success
-            message
-            }
-        }
-        """)
-        params = {'clusterId': cluster_id}
-
-        #  Send request to Grid.
-        success = False
-        try:
-            result = self.client.execute(mutation, variable_values=params)
-            result = result['deleteCluster']
-            message = result['message']
-
-            success = result['success']
-            if success is False:
-                click.echo(f'Cluster failed to delete: {message}')
-            else:
-                click.echo('Cluster deleted successfully')
-
-        #  Raise any other errors that the backend may raise.
-        except Exception as e:  # skipcq: PYL-W0703
-            message = ast.literal_eval(str(e))['message']
-            raise click.ClickException(message)
-
-        return success
-
-    def train(self, config: Dict, kind: WorkflowType, run_name: str,
-              run_description: str, entrypoint: str,
-              script_args: List[str]) -> None:
+    def train(self, config: str, kind: WorkflowType, run_name: str,
+              run_description: str, entrypoint: str, script_args: List[str],
+              invocation_command: str) -> None:
         """
         Submits a Run to backend from a local script.
 
@@ -535,6 +519,13 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
                                                       'github.com/')
         github_repository = github_repository.replace('.git', '')
 
+        if not self._check_github_repo_accessible(github_repository):
+            settings_url = env.GRID_URL.replace("graphql", "") + "#/settings"
+            click.launch(settings_url)
+            raise click.ClickException(
+                f'Grid cannot access {github_repository}. Please grant access on the settings page: {settings_url}'
+            )
+
         #  Build GraphQL query
         mutation = gql("""
         mutation (
@@ -544,6 +535,7 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
             $commitSha: String
             $githubRepository: ID!
             $commandLineArgs: [String]!
+            $invocationCommand: String!
             ) {
             trainScript (
                 properties: {
@@ -553,6 +545,7 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
                         configString: $configString
                         commitSha: $commitSha
                         commandLineArgs: $commandLineArgs
+                        invocationCommand: $invocationCommand
                     }
             ) {
             success
@@ -575,7 +568,8 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
             'description': run_description,
             'commitSha': commit_sha,
             'githubRepository': github_repository,
-            'commandLineArgs': script_args
+            'commandLineArgs': script_args,
+            'invocationCommand': invocation_command
         }
 
         #  Send request to Grid.
@@ -1164,10 +1158,12 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
         query = gql("""
         query (
             $experimentId: ID!
-
         ) {
             getExperimentDetails(experimentId: $experimentId) {
                 experimentId
+                run {
+                  name
+                }
                 status
             }
         }
@@ -1212,6 +1208,13 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
 
         # Check if Experiment is queued.
         state = experiment_details['getExperimentDetails']['status']
+
+        if state is None or state == 'deleted':
+            spinner.fail("✘")
+            spinner.stop()
+            raise click.ClickException(
+                f"""Could not find experiment {experiment_id}""")
+
         if state == 'queued':
             spinner.ok("✔")
             styled_queued = click.style('queued', fg='yellow')
@@ -1356,6 +1359,7 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
             }
 
             # Create websocket connection.
+            connection_closed_message = "Connection closed. Please try again."
             try:
                 stream = self.client.subscribe(subscription,
                                                variable_values=params)
@@ -1384,23 +1388,18 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
 
             # If connection is suddenly closed, indicate that a
             # known error happened.
-            except websockets.exceptions.ConnectionClosedError:
+            except websockets.exceptions.ConnectionClosed:
                 spinner.fail("✘")
-                raise click.ClickException('Could not fetch log data.')
+                raise click.ClickException(connection_closed_message)
 
             except websockets.exceptions.ConnectionClosedOK:
                 spinner.fail("✘")
                 raise click.ClickException(
                     'Could not continue fetching log stream.')
 
-            #  Raise any other errors that the backend may raise.
+            # Raise any other errors that the backend may raise.
             except Exception as e:  # skipcq: PYL-W0703
-                spinner.fail("✘")
-                if 'Server error:' in str(e):
-                    e = str(e).replace('Server error: ', '')[1:-1]
-
-                message = ast.literal_eval(str(e))['message']
-                raise click.ClickException(message)
+                raise click.ClickException(connection_closed_message)
 
         #  Makes sure to close the spinner in all situations.
         #  If we don't do this, the tracker character in the terminal
@@ -1800,6 +1799,52 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
         click.echo("")
         self.__print_datastore_sessions(sessions)
 
+    def validate_datastore_version(self, grid_config: dict):
+        """
+        Find maximum version of a datastore (ready to attach) and set config accordingly.
+        No-op if config does not contain datastore name or already contains a set datastore version.
+        """
+        try:
+            datastore_name = grid_config["compute"]["train"]["datastore_name"]
+            datastore_version = grid_config["compute"]["train"][
+                "datastore_version"]
+        except:
+            return
+
+        if datastore_version or not datastore_name:
+            return
+
+        query = gql("""
+            query GetDatastores {
+                getDatastores {
+                    name
+                    version
+                    snapshotStatus
+                }
+            }
+        """)
+
+        try:
+            result = self.client.execute(query)
+        except TransportQueryError as e:
+            raise click.ClickException(f"Unable to list datastores: {e}")
+
+        max_version = -1
+        for row in result["getDatastores"]:
+            if datastore_name == row["name"] and row[
+                    'snapshotStatus'] == "succeeded":
+                max_version = max(max_version, int(row["version"]))
+
+        if max_version == -1:
+            raise click.ClickException(
+                f'No --grid_datastore_version passed for datastore: {datastore_name}, but unable to find a ready-to-use version.'
+            )
+
+        click.echo(
+            f'No --grid_datastore_version passed for datastore: {datastore_name}. Using version: {max_version}'
+        )
+        grid_config["compute"]["train"]["datastore_version"] = str(max_version)
+
     def list_datastores(self):
         """
         List datastores for user
@@ -2165,9 +2210,8 @@ class Grid(CredentialsMixin, WorkflowChecksMixin, DependencyMixin):
                 f"    User {ssh_url.username}",
                 f"    Hostname {ssh_url.hostname}",
                 f"    Port {ssh_url.port}",
-                "    ServerAliveInterval 20",
-                "    ServerAliveCountMax 3",
                 "    StrictHostKeyChecking accept-new",
+                "    CheckHostIP no",
             ])
         managed_part.append(end_marker)
 
