@@ -388,7 +388,8 @@ class DatastoreUploadSession(UploadProgressCallback):
         split_size = get_split_size(self.compressed_size)
         self.part_count = math.ceil(self.compressed_size / split_size)
 
-    def _create_uploader(self, presigned_urls: Dict[int, str]):
+    def _create_uploader(self, presigned_urls: Dict[int, str],
+                         already_uploaded_parts: List[int]):
         size = self.compressed_size
         if size == 0:
             # We added compressed size later, so if a session didn't have it serialized,
@@ -400,6 +401,7 @@ class DatastoreUploadSession(UploadProgressCallback):
 
         return S3Uploader(source_file=self.target_file,
                           presigned_urls=presigned_urls,
+                          already_uploaded_parts=already_uploaded_parts,
                           name=f"{self.name}-{self.version}",
                           split_size=split_size,
                           total_size=size,
@@ -410,15 +412,20 @@ class DatastoreUploadSession(UploadProgressCallback):
             f"Uploading datastore {self.name} (v{self.version}) datastore" +
             " to S3...")
 
-        # Skip uploading parts that is already uploaded.
+        # Split urls depending on whether they were already uploaded or not.
         # This can happen if we resume an upload session.
+        # The already uploaded ones are useful to show an accurate progress percentage.
         unuploaded_presigned_urls = {}
+        already_uploaded_parts = []
         for part, url in self.presigned_urls.items():
             if part not in self.etags:
                 unuploaded_presigned_urls[part] = url
+            else:
+                already_uploaded_parts.append(part)
 
         uploader = self._create_uploader(
-            presigned_urls=unuploaded_presigned_urls)
+            presigned_urls=unuploaded_presigned_urls,
+            already_uploaded_parts=already_uploaded_parts)
 
         # Stoping and starting the spinner, as the progress bar
         # in uploader will conflict with the spinner
