@@ -8,6 +8,9 @@ from dataclasses import dataclass
 from functools import partial
 import os.path
 from pathlib import Path
+import signal
+from threading import Event
+from time import sleep
 from typing import List, Optional
 from urllib.request import urlopen
 
@@ -19,6 +22,17 @@ from rich.progress import TextColumn
 from rich.progress import TimeRemainingColumn
 from rich.progress import TransferSpeedColumn
 
+# Handles interruption events.
+DONE_EVENT = Event()
+
+
+def _handle_sigint(*args):
+    DONE_EVENT.set()
+
+
+# signal.signal(signal.SIGKILL, _handle_sigint)
+signal.signal(signal.SIGINT, _handle_sigint)
+
 
 @dataclass
 class DownloadableObject:
@@ -64,15 +78,20 @@ class Downloader:
         # skipcq: BAN-B310
         response = urlopen(url)
 
-        # This will break if the response doesn't contain content length
-        self.progress.update(task_id,
-                             total=int(response.info()['Content-length']))
-        with open(path, 'wb') as dest_file:
+        # This will break if the response doesn't contain content length.
+        # Grid objects always have Content-length
+        content_length = int(response.info()["Content-Length"])
+        self.progress.update(task_id, total=content_length)
+        with open(path, "wb") as dest_file:
             self.progress.start_task(task_id)
-            for data in iter(partial(response.read, 32768), b''):
+            for data in iter(partial(response.read, 32768), b""):
                 dest_file.write(data)
                 self.progress.update(task_id, advance=len(data))
 
+                # Cancel downlad midway
+                if DONE_EVENT.is_set():
+                    return
+
     @staticmethod
     def create_dir_tree(dest_dir: str, base_dir: Optional[str] = None) -> None:
         """
@@ -111,7 +130,31 @@ class Downloader:
                         'download',
                         filename=file_to_download.filename,
                         start=False)
+
                     pool.submit(self._get_file, task_id, file_to_download.url,
                                 dest_path)
 
+                    if DONE_EVENT.is_set():
+                        return
+
         return True
+
+
+# NOTE: I am leaving this here to improve developer UX
+# and debugability for this area. I'm inclined to refactor
+# this as stated here: CORE-2644
+# if __name__ == '__main__':
+#     url = 'https://www.google.com/images/branding/googlelogo/2x/googlelogo_color_272x92dp.png'
+#     directory_path = 'nested_0/nested_1'
+#     filename = 'test-filename.png'
+#     objects = []
+
+#     for i in range(10):
+#         objects.append(
+#         DownloadableObject(url=url,
+#                             download_path=directory_path,
+#                             filename=filename))
+
+#     # Download file
+#     D = Downloader(downloadable_objects=objects, base_dir='foo')
+#     D.download()
