@@ -58,18 +58,6 @@ class TestStatus:
         # Set attribute again.
         monkeypatch.setattr(Grid, 'status', old_status)
 
-    def test_status_raises_exception(self, monkeypatch):
-        """grid status raises exception when experiment is passed"""
-        old_status = Grid.status
-        monkeypatch.setattr(Grid, 'status', self.monkey_patched_method)
-
-        result = self.runner.invoke(cli.status, [f'{self.test_run}-exp1'])
-        assert result.exit_code == 2
-        assert result.exception
-
-        # Set attribute again.
-        monkeypatch.setattr(Grid, 'status', old_status)
-
     def test_status_run(self, monkeypatch):
         """grid status interactive nodes output toggles with the run param"""
         old_status = Grid.status
