@@ -1,10 +1,15 @@
+import uuid
+
 import click
 from click.testing import CliRunner
 from tests.mock_backend import GridAIBackenedTestServer
+from tests.mock_backend import resolvers
 from tests.utilities import create_test_credentials
+from tests.utilities import monkey_patch_client
 
 from grid import cli
 from grid.client import Grid
+import grid.client as grid
 import grid.globals as env
 
 
@@ -22,11 +27,8 @@ class TestView:
         env.DEBUG = True
 
         #  Monkey patches the GraphQL client to read from a local schema.
-        def monkey_patch_client(self):
-            self.client = GridAIBackenedTestServer()
-
-        #  skipcq: PYL-W0212
-        Grid._init_client = monkey_patch_client
+        grid.Grid._init_client = monkey_patch_client
+        grid.gql = lambda x: x
 
         create_test_credentials()
 
@@ -55,14 +57,15 @@ class TestView:
         """grid view RUN_ID opens browser."""
         monkeypatch.setattr(click, 'launch', self.monkey_patched_method)
 
-        result = self.runner.invoke(cli.view, [self.test_run])
+        result = self.runner.invoke(cli.view, ["run", self.test_run])
 
         assert result.exit_code == 0
         assert 'http' in result.output
         assert 'run' in result.output
         assert self.test_run in result.output
 
-        result = self.runner.invoke(cli.view, [f'{self.test_run}-exp1'])
+        result = self.runner.invoke(cli.view,
+                                    ["experiment", f'{self.test_run}-exp1'])
         assert result.exit_code == 0
         assert 'http' in result.output
         assert 'experiment' in result.output
@@ -75,11 +78,13 @@ class TestView:
         old_status = Grid.status
         monkeypatch.setattr(Grid, 'status', self.monkey_patch_exception)
 
-        result = self.runner.invoke(cli.view, [self.test_run, 'tensorboard'])
+        result = self.runner.invoke(cli.view,
+                                    ["run", self.test_run, 'tensorboard'])
         assert result.exit_code == 1
         assert result.exception
 
-        result = self.runner.invoke(cli.view, [self.test_run, 'tensorboard'])
+        result = self.runner.invoke(cli.view,
+                                    ["run", self.test_run, 'tensorboard'])
         assert result.exit_code == 1
         assert result.exception
 
@@ -89,12 +94,20 @@ class TestView:
     def test_view_right_url_for_services(self, monkeypatch):
         """grid view generates the right URLs for services."""
         monkeypatch.setattr(click, 'launch', self.monkey_patched_method)
-
-        old_status = Grid.status
         monkeypatch.setattr(Grid, 'status', self.monkey_patch_grid_status)
 
-        for arg in [self.test_run, self.test_exp]:
-            result = self.runner.invoke(cli.view, [arg, 'tensorboard'])
+        def f(*args, **kwargs):
+            return {
+                'status': 'succeeded',
+                "run": {
+                    "name": self.test_run,
+                }
+            }
+
+        monkeypatch.setattr(resolvers, 'get_experiment_details', f)
+
+        for tt, arg in [("run", self.test_run), ("experiment", self.test_exp)]:
+            result = self.runner.invoke(cli.view, [tt, arg, 'tensorboard'])
             assert result.exit_code == 0
             assert not result.exception
             assert 'http' in result.output
@@ -102,17 +115,15 @@ class TestView:
             # Test that the Tensorboard URL constructor is there.
             assert 'scalars&regexInput=' in result.output
 
-        # Set attribute again.
-        monkeypatch.setattr(Grid, 'status', old_status)
-
     def test_view_fail_tensorboard_not_ready(self, monkeypatch):
         """grid view fails when tensorboard is not ready."""
         old_status = Grid.status
         monkeypatch.setattr(Grid, 'status',
                             self.monkey_patch_grid_status_not_ready)
 
-        result = self.runner.invoke(cli.view, [self.test_run, 'tensorboard'])
-        assert result.exit_code == 1
+        result = self.runner.invoke(cli.view,
+                                    ["run", self.test_run, 'tensorboard'])
+        assert result.exit_code != 0
         assert result.exception
         assert "Tensorboard isn't ready yet" in result.output
 
