@@ -12,6 +12,7 @@ import zlib
 import click
 from click.exceptions import ClickException
 from gql import Client
+from gql.transport.exceptions import TransportQueryError
 import httpretty
 import pytest
 import requests
@@ -88,12 +89,19 @@ class TestGridClient:
         cls.grid_header_keys = ['X-Grid-User', 'X-Grid-Key']
 
         cls.train_kwargs = {
-            'config': 'test-config',
-            'kind': WorkflowType.SCRIPT,
-            'run_name': 'test-run',
-            'run_description': 'test description',
-            'entrypoint': 'test_file.py',
-            'script_args': ['--learning_rate', '0.001']
+            'config':
+            'test-config',
+            'kind':
+            WorkflowType.SCRIPT,
+            'run_name':
+            'test-run',
+            'run_description':
+            'test description',
+            'entrypoint':
+            'test_file.py',
+            'script_args': ['--learning_rate', '0.001'],
+            'invocation_command':
+            'grid train --grid_name test-run --grid_description "test description" test_file.py --learning_rate 0.001'
         }
 
     def remove_env(self):
@@ -222,6 +230,27 @@ class TestGridClient:
         env.DEBUG = True
         G.train(**self.train_kwargs)
 
+    def test_train_raises_exception_github_not_accessible(self, monkeypatch):
+        """grid.Grid().train() raises exception if the user did not authorize
+        access to a private repo."""
+        G = grid.Grid(load_local_credentials=False)
+        G._init_client()
+
+        env.IGNORE_WARNINGS = True
+
+        def monkey_patch_is_github_repository_accessible(*args, **kwargs):
+            return {
+                "isAccessible": False,
+            }
+
+        with pytest.raises(click.exceptions.ClickException) as ex_info:
+            monkeypatch.setattr(resolvers, 'is_github_repository_accessible',
+                                monkey_patch_is_github_repository_accessible)
+            G.train(**self.train_kwargs)
+
+        assert "Please grant access on the settings page" in ex_info.value.args[
+            0]
+
     def test_train_raises_exception_blueprint(self):
         """
         grid.Grid().train() raises exception when attempting to
@@ -238,6 +267,7 @@ class TestGridClient:
                       load_local_credentials=False)
         G.client = MonkeyPatchClient()
         G._check_user_github_token = lambda: True
+        G._check_github_repo_accessible = lambda _: True
         env.IGNORE_WARNINGS = True
 
         with pytest.raises(click.ClickException):
@@ -387,31 +417,131 @@ class TestGridClient:
             G.login(username='test-user', key='test-key')
 
     @staticmethod
-    def test_delete_cluster(monkeypatch):
-        """Grid().delete_cluster() deletes a cluster."""
+    def test_validate_datastore_version_exception(monkeypatch):
         G = grid.Grid(load_local_credentials=False)
         G._init_client()
 
-        assert G.delete_cluster(cluster_id='test-cluster')
+        env.DEBUG = True
 
-        def monkey_patch_delete_cluster(*args, **kwargs):
-            return {'success': False, 'message': ''}
+        def monkey_path_get_datastores_exc(*args, **kwargs):
+            raise TransportQueryError(msg="")
 
-        monkeypatch.setattr(resolvers, 'delete_cluster',
-                            monkey_patch_delete_cluster)
-        assert not G.delete_cluster(cluster_id='test-cluster')
+        config = {
+            "compute": {
+                "train": {
+                    "datastore_name": "mnist",
+                    "datastore_version": None
+                }
+            }
+        }
+        with pytest.raises(click.ClickException) as ex_info:
+            monkeypatch.setattr(GridAIBackenedTestServer, 'execute',
+                                monkey_path_get_datastores_exc)
+            G.validate_datastore_version(grid_config=config)
+        assert "Unable to list datastores" in ex_info.value.args[0]
 
     @staticmethod
-    def test_delete_cluster_handles_api_error(monkeypatch):
-        """Grid().delete_cluster() handles API error."""
-        monkey_patch_delete_cluster = lambda: {}
-
+    def test_validate_datastore_version(monkeypatch):
         G = grid.Grid(load_local_credentials=False)
         G._init_client()
-        monkeypatch.setattr(resolvers, 'delete_cluster',
-                            monkey_patch_delete_cluster)
-        with pytest.raises(click.ClickException):
-            G.delete_cluster(cluster_id='test-cluster')
+
+        env.DEBUG = True
+
+        def monkey_path_get_datastores(*args, **kwargs):
+            return [
+                {
+                    'name': 'mnist',
+                    'version': '1',
+                    'snapshotStatus': 'succeeded'
+                },
+                {
+                    'name': 'mnist',
+                    'version': '2',
+                    'snapshotStatus': 'succeeded'
+                },
+                {
+                    'name': 'mnist',
+                    'version': '3',
+                    'snapshotStatus': 'unknown'
+                },
+            ]
+
+        monkeypatch.setattr(resolvers, 'get_datastores',
+                            monkey_path_get_datastores)
+        config = {}
+        G.validate_datastore_version(grid_config=config)
+        assert config == {}
+
+        config = {
+            "compute": {
+                "train": {
+                    "datastore_name": "mnist",
+                }
+            }
+        }
+        G.validate_datastore_version(grid_config=config)
+        assert config["compute"]["train"]["datastore_name"] == "mnist"
+        assert "datastore_version" not in config["compute"]["train"]
+
+        config = {
+            "compute": {
+                "train": {
+                    "datastore_name": "mnist",
+                    "datastore_version": None
+                }
+            }
+        }
+        G.validate_datastore_version(grid_config=config)
+        assert config["compute"]["train"]["datastore_name"] == "mnist"
+        assert config["compute"]["train"]["datastore_version"] == "2"
+
+        config = {
+            "compute": {
+                "train": {
+                    "datastore_name": "mnist",
+                    "datastore_version": ""
+                }
+            }
+        }
+        G.validate_datastore_version(grid_config=config)
+        assert config["compute"]["train"]["datastore_name"] == "mnist"
+        assert config["compute"]["train"]["datastore_version"] == "2"
+
+        config = {
+            "compute": {
+                "train": {
+                    "datastore_name": "mnist",
+                    "datastore_version": "1"
+                }
+            }
+        }
+        G.validate_datastore_version(grid_config=config)
+        assert config["compute"]["train"]["datastore_name"] == "mnist"
+        assert config["compute"]["train"]["datastore_version"] == "1"
+
+        config = {
+            "compute": {
+                "train": {
+                    "datastore_name": "wrong-name",
+                    "datastore_version": None
+                }
+            }
+        }
+        with pytest.raises(click.ClickException) as ex_info:
+            G.validate_datastore_version(grid_config=config)
+        assert "unable to find a ready-to-use version" in ex_info.value.args[0]
+
+        config = {
+            "compute": {
+                "train": {
+                    "datastore_name": "wrong-name",
+                    "datastore_version": "1"
+                }
+            }
+        }
+        G.validate_datastore_version(grid_config=config)
+        assert config["compute"]["train"]["datastore_name"] == "wrong-name"
+        assert config["compute"]["train"]["datastore_version"] == "1"
 
     @staticmethod
     def test_upload_datstore_handles_error():
@@ -807,6 +937,22 @@ class TestGridClient:
         G._init_client.assert_called_once()
         G.client.subscribe.assert_called_once()
 
+    def test_experiment_logs_deleted(self):
+        G = grid.Grid(credential_path=self.creds_path,
+                      load_local_credentials=False)
+
+        G.client = MagicMock()
+        G.experiment_details = MagicMock(return_value={
+            'getExperimentDetails': {
+                'status': 'deleted',
+                'experimentId': 'test'
+            }
+        })
+        with pytest.raises(ClickException) as ex_info:
+            G.experiment_logs('test')
+        assert "Could not find experiment" in ex_info.value.args[0]
+        G.client.execute.assert_not_called()
+
     def test_experiment_metrics_queued(self):
         G = grid.Grid(credential_path=self.creds_path,
                       load_local_credentials=False)
@@ -960,16 +1106,14 @@ class TestGridClient:
                 "    User jovyan",
                 "    Hostname ix1.grid.ai",
                 "    Port 233",
-                "    ServerAliveInterval 20",
-                "    ServerAliveCountMax 3",
                 "    StrictHostKeyChecking accept-new",
+                "    CheckHostIP no",
                 "Host ix2",
                 "    User jovyan",
                 "    Hostname ix2.grid.ai",
                 "    Port 433",
-                "    ServerAliveInterval 20",
-                "    ServerAliveCountMax 3",
                 "    StrictHostKeyChecking accept-new",
+                "    CheckHostIP no",
                 "#END",
             ])
 
@@ -993,16 +1137,14 @@ class TestGridClient:
                 "    User jovyan",
                 "    Hostname ix1.grid.ai",
                 "    Port 233",
-                "    ServerAliveInterval 20",
-                "    ServerAliveCountMax 3",
                 "    StrictHostKeyChecking accept-new",
+                "    CheckHostIP no",
                 "Host ix2",
                 "    User jovyan",
                 "    Hostname ix2.grid.ai",
                 "    Port 433",
-                "    ServerAliveInterval 20",
-                "    ServerAliveCountMax 3",
                 "    StrictHostKeyChecking accept-new",
+                "    CheckHostIP no",
                 "#END",
             ]),
             start_marker="#START",
@@ -1013,15 +1155,13 @@ class TestGridClient:
                 "    User jovyan",
                 "    Hostname ix1.grid.ai",
                 "    Port 233",
-                "    ServerAliveInterval 20",
-                "    ServerAliveCountMax 3",
                 "    StrictHostKeyChecking accept-new",
+                "    CheckHostIP no",
                 "Host ix2",
                 "    User jovyan",
                 "    Hostname ix2.grid.ai",
                 "    Port 433",
-                "    ServerAliveInterval 20",
-                "    ServerAliveCountMax 3",
                 "    StrictHostKeyChecking accept-new",
+                "    CheckHostIP no",
                 "#END",
             ])
