@@ -163,7 +163,7 @@ class TestDatastore:
             return TarResults(before_size=1024 * 1000 * 1000,
                               after_size=1024 * 1000 * 1000)
 
-        def create_uploader(presigned_urls):
+        def create_uploader(presigned_urls, already_uploaded_parts):
             return MockS3Uploader(session)
 
         monkeypatch.setattr('grid.datastore.tar_directory', tar_directory)
