@@ -25,10 +25,11 @@ def test_s3_uploader():
             3: "http://grid.ai/3",
             4: "http://grid.ai/4"
         }
+        already_uploaded_parts = [5]
 
         reverse_keys = {"aa": 1, "ab": 2, "ac": 3, "ad": 4}
 
-        def mock_upload_data(url, part_data, _):
+        def mock_upload_data(url, part_data, *args):
             found_key = None
             for k, d in data.items():
                 if part_data == d:
@@ -50,6 +51,7 @@ def test_s3_uploader():
         updater = MockProgressUpdater()
         uploader = S3Uploader(source_file=os.path.join(tmpdir, "data.tar.gz"),
                               presigned_urls=urls,
+                              already_uploaded_parts=already_uploaded_parts,
                               progress_callback=updater,
                               name="test",
                               total_size=256 * 4,
